==> syncthingtray_1.4.12.orig.tar.xz: syncthingtray-1.4.12/syncthingmodel/translations/syncthingmodel_de_DE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>Data::StatusIconSettings</name>
    <message>
        <location filename="../syncthingicons.cpp" line="229"/>
        <source>Misc. notifications</source>
        <translation>Benachrichtigungen</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="230"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="231"/>
        <source>Warning</source>
        <translation>Warnungen</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="232"/>
        <source>Idle</source>
        <translation>Leerlauf</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="233"/>
        <source>Scanning</source>
        <translation>Scannen</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="234"/>
        <source>Synchronizing</source>
        <translation>Synchronisieren</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="235"/>
        <source>Paused</source>
        <translation>Pausiert</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="236"/>
        <source>Disconnected</source>
        <translation>Getrennt</translation>
    </message>
</context>
<context>
    <name>Data::SyncthingDeviceModel</name>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="86"/>
        <location filename="../syncthingdevicemodel.cpp" line="118"/>
        <source>ID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="88"/>
        <source>Status</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="120"/>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="122"/>
        <source>Connection type</source>
        <translation>Verbindungstyp</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="124"/>
        <source>Last seen</source>
        <translation>Zuletzt gesehen</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="126"/>
        <source>Compression</source>
        <translation>Kompression</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="128"/>
        <source>Certificate</source>
        <translation>Zertifikat</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="130"/>
        <source>Introducer</source>
        <translation>Verteilergerät</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="132"/>
        <source>Incoming traffic</source>
        <translation>Eingehender Datenverkehr</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="134"/>
        <source>Outgoing traffic</source>
        <translation>Ausgehender Datenverkehr</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="136"/>
        <source>Version</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="157"/>
        <source>local</source>
        <translation>lokal</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="157"/>
        <source>remote</source>
        <translation>entfernt</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="162"/>
        <source>unknown or this device</source>
        <translation>unbekannt oder eigenes Gerät</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="167"/>
        <source>none</source>
        <translation>keines</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="169"/>
        <source>yes</source>
        <translation>ja</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="169"/>
        <source>no</source>
        <translation>nein</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="380"/>
        <source>Paused</source>
        <translation>Pausiert</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="384"/>
        <source>Unknown status</source>
        <translation>Unbekannter Status</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="386"/>
        <source>This device</source>
        <translation>Dieses Gerät</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="388"/>
        <source>Idle</source>
        <translation>Leerlauf</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="390"/>
        <source>Disconnected</source>
        <translation>Getrennt</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="395"/>
        <source>Synchronizing</source>
        <translation>Synchronisiert</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="392"/>
        <source>Synchronizing (%1 %, %2)</source>
        <translation>Synchronisieren (%1 %, %2)</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="397"/>
        <source>Out of sync</source>
        <translation>Nicht synchronisiert</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="399"/>
        <source>Rejected</source>
        <translation>Zurückgewiesen</translation>
    </message>
</context>
<context>
    <name>Data::SyncthingDirectoryModel</name>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="92"/>
        <location filename="../syncthingdirectorymodel.cpp" line="124"/>
        <source>ID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="94"/>
        <source>Status</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="126"/>
        <source>Path</source>
        <translation>Pfad</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="136"/>
        <source>Rescan interval</source>
        <translation>Scanintervall</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="138"/>
        <source>Last scan</source>
        <translation>Letzter Scan</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="140"/>
        <source>Last file</source>
        <translation>Letzte Datei</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="142"/>
        <source>Errors</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="165"/>
        <source>not shared</source>
        <translation>nicht geteilt</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="172"/>
        <location filename="../syncthingdirectorymodel.cpp" line="175"/>
        <source>unknown</source>
        <translation>unbekannt</translation>
    </message>
    <message numerus="yes">
        <location filename="../syncthingdirectorymodel.cpp" line="186"/>
        <source>%1 and %2 item(s) out of sync</source>
        <translation>
            <numerusform>&quot;%1&quot; und %2 Element nicht synchronisiert</numerusform>
            <numerusform>&quot;%1&quot; und %2 Elemente nicht synchronisiert</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="178"/>
        <source>none</source>
        <translation>keine</translation>
    </message>
    <message numerus="yes">
        <location filename="../syncthingdirectorymodel.cpp" line="184"/>
        <source>%1 item(s) out of sync</source>
        <translation>
            <numerusform>%1 Element nicht synchronisiert</numerusform>
            <numerusform>%1 Elemente nicht synchronisiert</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="260"/>
        <source>Deleted at %1</source>
        <translation>Gelöscht am %1</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="263"/>
        <source>Updated at %1</source>
        <translation>Aktualisiert am %1</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="276"/>
        <source>Click for details</source>
        <translation>Für details klicken</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="275"/>
        <source>Failed items</source>
        <translation>Fehlgeschlagene Elemente</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="466"/>
        <source>Unknown status</source>
        <translation>Unbekannter Status</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="468"/>
        <source>Idle</source>
        <translation>Leerlauf</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="462"/>
        <source>Unshared</source>
        <translation>Nicht geteilt</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="128"/>
        <source>Global status</source>
        <translation>Globaler status</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="130"/>
        <source>Local status</source>
        <translation>Lokaler status</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="132"/>
        <source>Shared with</source>
        <translation>Geteilt mit</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="134"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="470"/>
        <source>Waiting to scan</source>
        <translation>Warten aufs Scannen</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="474"/>
        <source>Scanning (%1 %, %2)</source>
        <translation>Scannen (%1 %, %2)</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="476"/>
        <source>Scanning (%1 %)</source>
        <translation>Scannen (%1 %)</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="478"/>
        <source>Scanning</source>
        <translation>Scannen</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="480"/>
        <source>Waiting to sync</source>
        <translation>Warten aufs Synchronisieren</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="482"/>
        <source>Preparing to sync</source>
        <translation>Vorbereiten aufs Synchronisieren</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="484"/>
        <source>Synchronizing (%1 %)</source>
        <translation>Synchronisieren (%1 %)</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="484"/>
        <source>Synchronizing</source>
        <translation>Synchronisieren</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="459"/>
        <source>Paused</source>
        <translation>Pausiert</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="486"/>
        <source>Cleaning</source>
        <translation>Versionen bereinigen</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="488"/>
        <source>Waiting to clean</source>
        <translation>Warten auf Bereinigung</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="490"/>
        <source>Out of sync</source>
        <translation>Nicht synchronisiert</translation>
    </message>
</context>
<context>
    <name>Data::SyncthingDownloadModel</name>
    <message>
        <location filename="../syncthingdownloadmodel.cpp" line="96"/>
        <source>Dir/item</source>
        <translation>Ordner/Element</translation>
    </message>
    <message>
        <location filename="../syncthingdownloadmodel.cpp" line="98"/>
        <source>Progress</source>
        <translation>Fortschritt</translation>
    </message>
</context>
<context>
    <name>Data::SyncthingRecentChangesModel</name>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="71"/>
        <source>Action</source>
        <translation>Aktion</translation>
    </message>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="73"/>
        <source>Device</source>
        <translation>Gerät</translation>
    </message>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="75"/>
        <source>Folder</source>
        <translation>Ordner</translation>
    </message>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="77"/>
        <source>Path</source>
        <translation>Pfad</translation>
    </message>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="119"/>
        <source>Locally</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="119"/>
        <source>Remotely</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Data::SyncthingStatusComputionModel</name>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="37"/>
        <source>Local dir is scanning</source>
        <translation>Lokaler Ordner wird gescannt</translation>
    </message>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="39"/>
        <source>Local dir is synchronizing</source>
        <translation>Lokaler Ordner wird synchronisiert</translation>
    </message>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="41"/>
        <source>Remote dir has outstanding progress</source>
        <translation>Entfernter Ordner hat ausstehende Elemente</translation>
    </message>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="43"/>
        <source>A device is paused</source>
        <translation>Ein Gerät ist pausiert</translation>
    </message>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="45"/>
        <source>Local dir is out of sync</source>
        <translation>Lokaler Ordner ist nicht synchronisiert</translation>
    </message>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="47"/>
        <source>Unread notification present</source>
        <translation>Ungelesene Benachrichtigungen</translation>
    </message>
</context>
</TS>

==> syncthingtray_1.5.2.orig.tar.xz: syncthingtray-1.5.2/syncthingmodel/translations/syncthingmodel_de_DE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>Data::StatusIconSettings</name>
    <message>
        <location filename="../syncthingicons.cpp" line="229"/>
        <source>Misc. notifications</source>
        <translation>Benachrichtigungen</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="230"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="231"/>
        <source>Warning</source>
        <translation>Warnungen</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="232"/>
        <source>Idle</source>
        <translation>Leerlauf</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="233"/>
        <source>Scanning</source>
        <translation>Scannen</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="234"/>
        <source>Synchronizing</source>
        <translation>Synchronisieren</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="235"/>
        <source>Paused</source>
        <translation>Pausiert</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="236"/>
        <source>Disconnected</source>
        <translation>Getrennt</translation>
    </message>
</context>
<context>
    <name>Data::SyncthingDeviceModel</name>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="86"/>
        <location filename="../syncthingdevicemodel.cpp" line="118"/>
        <source>ID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="88"/>
        <source>Status</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="120"/>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="122"/>
        <source>Connection type</source>
        <translation>Verbindungstyp</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="124"/>
        <source>Last seen</source>
        <translation>Zuletzt gesehen</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="126"/>
        <source>Compression</source>
        <translation>Kompression</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="128"/>
        <source>Certificate</source>
        <translation>Zertifikat</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="130"/>
        <source>Introducer</source>
        <translation>Verteilergerät</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="132"/>
        <source>Incoming traffic</source>
        <translation>Eingehender Datenverkehr</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="134"/>
        <source>Outgoing traffic</source>
        <translation>Ausgehender Datenverkehr</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="136"/>
        <source>Version</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="157"/>
        <source>local</source>
        <translation>lokal</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="157"/>
        <source>remote</source>
        <translation>entfernt</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="162"/>
        <source>unknown or this device</source>
        <translation>unbekannt oder eigenes Gerät</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="167"/>
        <source>none</source>
        <translation>keines</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="169"/>
        <source>yes</source>
        <translation>ja</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="169"/>
        <source>no</source>
        <translation>nein</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="380"/>
        <source>Paused</source>
        <translation>Pausiert</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="384"/>
        <source>Unknown status</source>
        <translation>Unbekannter Status</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="386"/>
        <source>This device</source>
        <translation>Dieses Gerät</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="388"/>
        <source>Idle</source>
        <translation>Leerlauf</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="390"/>
        <source>Disconnected</source>
        <translation>Getrennt</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="395"/>
        <source>Synchronizing</source>
        <translation>Synchronisiert</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="392"/>
        <source>Synchronizing (%1 %, %2)</source>
        <translation>Synchronisieren (%1 %, %2)</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="397"/>
        <source>Out of sync</source>
        <translation>Nicht synchronisiert</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="399"/>
        <source>Rejected</source>
        <translation>Zurückgewiesen</translation>
    </message>
</context>
<context>
    <name>Data::SyncthingDirectoryModel</name>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="92"/>
        <location filename="../syncthingdirectorymodel.cpp" line="124"/>
        <source>ID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="94"/>
        <source>Status</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="126"/>
        <source>Path</source>
        <translation>Pfad</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="136"/>
        <source>Rescan interval</source>
        <translation>Scanintervall</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="138"/>
        <source>Last scan</source>
        <translation>Letzter Scan</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="140"/>
        <source>Last file</source>
        <translation>Letzte Datei</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="142"/>
        <source>Errors</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="165"/>
        <source>not shared</source>
        <translation>nicht geteilt</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="172"/>
        <location filename="../syncthingdirectorymodel.cpp" line="175"/>
        <source>unknown</source>
        <translation>unbekannt</translation>
    </message>
    <message numerus="yes">
        <location filename="../syncthingdirectorymodel.cpp" line="186"/>
        <source>%1 and %2 item(s) out of sync</source>
        <translation>
            <numerusform>&quot;%1&quot; und %2 Element nicht synchronisiert</numerusform>
            <numerusform>&quot;%1&quot; und %2 Elemente nicht synchronisiert</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="178"/>
        <source>none</source>
        <translation>keine</translation>
    </message>
    <message numerus="yes">
        <location filename="../syncthingdirectorymodel.cpp" line="184"/>
        <source>%1 item(s) out of sync</source>
        <translation>
            <numerusform>%1 Element nicht synchronisiert</numerusform>
            <numerusform>%1 Elemente nicht synchronisiert</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="260"/>
        <source>Deleted at %1</source>
        <translation>Gelöscht am %1</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="263"/>
        <source>Updated at %1</source>
        <translation>Aktualisiert am %1</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="276"/>
        <source>Click for details</source>
        <translation>Für details klicken</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="275"/>
        <source>Failed items</source>
        <translation>Fehlgeschlagene Elemente</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="466"/>
        <source>Unknown status</source>
        <translation>Unbekannter Status</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="468"/>
        <source>Idle</source>
        <translation>Leerlauf</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="462"/>
        <source>Unshared</source>
        <translation>Nicht geteilt</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="128"/>
        <source>Global status</source>
        <translation>Globaler status</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="130"/>
        <source>Local status</source>
        <translation>Lokaler status</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="132"/>
        <source>Shared with</source>
        <translation>Geteilt mit</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="134"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="470"/>
        <source>Waiting to scan</source>
        <translation>Warten aufs Scannen</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="474"/>
        <source>Scanning (%1 %, %2)</source>
        <translation>Scannen (%1 %, %2)</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="476"/>
        <source>Scanning (%1 %)</source>
        <translation>Scannen (%1 %)</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="478"/>
        <source>Scanning</source>
        <translation>Scannen</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="480"/>
        <source>Waiting to sync</source>
        <translation>Warten aufs Synchronisieren</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="482"/>
        <source>Preparing to sync</source>
        <translation>Vorbereiten aufs Synchronisieren</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="484"/>
        <source>Synchronizing (%1 %)</source>
        <translation>Synchronisieren (%1 %)</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="484"/>
        <source>Synchronizing</source>
        <translation>Synchronisieren</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="459"/>
        <source>Paused</source>
        <translation>Pausiert</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="486"/>
        <source>Cleaning</source>
        <translation>Versionen bereinigen</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="488"/>
        <source>Waiting to clean</source>
        <translation>Warten auf Bereinigung</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="490"/>
        <source>Out of sync</source>
        <translation>Nicht synchronisiert</translation>
    </message>
</context>
<context>
    <name>Data::SyncthingDownloadModel</name>
    <message>
        <location filename="../syncthingdownloadmodel.cpp" line="96"/>
        <source>Dir/item</source>
        <translation>Ordner/Element</translation>
    </message>
    <message>
        <location filename="../syncthingdownloadmodel.cpp" line="98"/>
        <source>Progress</source>
        <translation>Fortschritt</translation>
    </message>
</context>
<context>
    <name>Data::SyncthingFileModel</name>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="141"/>
        <source>Name</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="143"/>
        <source>Size</source>
        <translation>Größe</translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="145"/>
        <source>Last modified</source>
        <translation>Zuletzt geändert</translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="201"/>
        <source>Refresh</source>
        <translation>Aktualisieren</translation>
    </message>
</context>
<context>
    <name>Data::SyncthingRecentChangesModel</name>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="71"/>
        <source>Action</source>
        <translation>Aktion</translation>
    </message>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="73"/>
        <source>Device</source>
        <translation>Gerät</translation>
    </message>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="75"/>
        <source>Folder</source>
        <translation>Ordner</translation>
    </message>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="77"/>
        <source>Path</source>
        <translation>Pfad</translation>
    </message>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="119"/>
        <source>Locally</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="119"/>
        <source>Remotely</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Data::SyncthingStatusComputionModel</name>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="37"/>
        <source>Local dir is scanning</source>
        <translation>Lokaler Ordner wird gescannt</translation>
    </message>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="39"/>
        <source>Local dir is synchronizing</source>
        <translation>Lokaler Ordner wird synchronisiert</translation>
    </message>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="41"/>
        <source>Remote dir has outstanding progress</source>
        <translation>Entfernter Ordner hat ausstehende Elemente</translation>
    </message>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="43"/>
        <source>A device is paused</source>
        <translation>Ein Gerät ist pausiert</translation>
    </message>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="45"/>
        <source>Local dir is out of sync</source>
        <translation>Lokaler Ordner ist nicht synchronisiert</translation>
    </message>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="47"/>
        <source>Unread notification present</source>
        <translation>Ungelesene Benachrichtigungen</translation>
    </message>
</context>
</TS>
